/** @file fpga_device.h
 *
 *  @brief Library for FPGA device Convention
 *
 *  @author alen.arias.vazquez@cern.ch
 *  @date 12/05/2022
 *  @url https://ohwr.org/project/fpga-dev-id/wikis/home
 *
 */

#ifndef __FPGA_DEVICE_H
#define __FPGA_DEVICE_H

#ifdef __cplusplus
extern "C" {
#endif

/***************************** Include Files **********************************/
#include <limits.h>
#include <stdlib.h>
#include <stdio.h>
#include <stdint.h>
#include <string.h>
#include <time.h>
#include <unistd.h>
#include <byteswap.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <sys/mman.h>
#include <errno.h>
#include <stdbool.h>

#include "diot_util.h"

/************************** Constant Definitions ******************************/
/***************** Macros (Inline Functions) Definitions **********************/
#define c_ADDR_VENDOR_ID     0x00
#define c_ADDR_DEVICE_ID     0x01
#define c_ADDR_VERSION       0x02
#define c_ADDR_BYTE_ORD_MARK 0x03
#define c_ADDR_SOURCE_ID_0   0x04
#define c_ADDR_SOURCE_ID_1   0x05
#define c_ADDR_SOURCE_ID_2   0x06
#define c_ADDR_SOURCE_ID_3   0x07
#define c_ADDR_CAP_MASK      0x08
#define c_ADDR_VENDOR_UUID_0 0x0C
#define c_ADDR_VENDOR_UUID_1 0x0D
#define c_ADDR_VENDOR_UUID_2 0x0E
#define c_ADDR_VENDOR_UUID_3 0x0F
#define c_ADDR_CORE_ID       0x10
#define c_ADDR_NAME_LSB      0x11
#define c_ADDR_NAME_MSB      0x12
#define c_ADDR_BUILD_T       0x13
#define c_ADDR_HASH_0        0x14
#define c_ADDR_HASH_1        0x15
#define c_ADDR_HASH_2        0x16
#define c_ADDR_HASH_3        0x17
#define c_ADDR_HASH_4        0x18
#define c_ADDR_DNA_0         0x19
#define c_ADDR_DNA_1         0x1A
#define c_ADDR_DNA_2         0x1B
#define c_ADDR_TAG_LSB       0x1C
#define c_ADDR_TAG_MSB       0x1D

#define c_ADDR_IP_CORE 0x80000000
#define c_SIZE_BYTES c_ADDR_TAG_MSB*4

/**************************** Type Definitions ********************************/
/******************************** Structs *************************************/
extern struct command_entry commands_list_fpga_device[];

/************************** Variable Definitions ******************************/
/************************** Function Prototypes *******************************/
int cmd_fpga (char *params);
int get_fpga_status(bool full_info);

#ifdef __cplusplus
}
#endif

#endif /* __FPGA_DEVICE_H */
